/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "sdpmLine2.h"

using namespace sdpm;

Line2::Line2(size_t n, Tag *tag, std::vector<Node *> &nodes) : Element(n, tag, nodes)
{
    // Compute unscaled values
    update(1.);
    _cg0 = _cg;
    _srf0 = _srf;
    _nrm0 = _nrm;
    _toDate = false;
}

/**
 * @brief Update precomputed values and gradients
 */
void Line2::update(double beta)
{
    Element::update(beta);                   // cg
    _srf = (_coords[1] - _coords[0]).norm(); // volume
    _nrm = sdpmVector3d::Zero();             // unit normal
    _toDate = true;
}
