/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#include "sdpm.h"
#include "sdpmMotion.h"
#include "sdpmElement.h"

using namespace sdpm;

Motion::Motion(sdpmDouble xvel, sdpmDouble amp, sdpmDouble xref) : sdpmObject(),
                                                                   _xVel(xvel), _amp(amp), _xRef(xref)
{
}

/**
 * @brief Compute the steady part of the motion induced velocity on an element of the body
 */
sdpmVector3cd Motion::computeSteady(Element const &e)
{
    return sdpmVector3cd(0., 0., _xVel * _amp);
}

/**
 * @brief Compute the harmonic part of the motion induced velocity on an element of the body
 */
sdpmVector3cd Motion::computeHarmonic(Element const &e)
{
    sdpmVector3d cg = e.getCompressibleCg();
    return sdpmVector3cd(-_amp * cg(2), 0., _amp * (cg(0) - _xRef));
}
