/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMMOTION_H
#define SDPMMOTION_H

#include "sdpm.h"
#include "sdpmObject.h"

namespace sdpm
{

/**
 * @brief Hold the parameters defning the motion of a body and compute the induced velocity
 * @authors Adrien Crovato
 * @todo support several types of motion and combinations
 */
class SDPM_API Motion : public sdpmObject
{
    sdpmDouble _xVel;
    sdpmDouble _amp;
    sdpmDouble _xRef;

public:
    Motion(sdpmDouble xvel, sdpmDouble amp, sdpmDouble xref);
    ~Motion(){};

    sdpmDouble getAmplitude() const { return _amp; }
    sdpmVector3cd computeSteady(Element const &e);
    sdpmVector3cd computeHarmonic(Element const &e);
};

} // namespace sdpm

#endif // SDPMMOTION_H
