/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMQUAD4_H
#define SDPMQUAD4_H

#include "sdpm.h"
#include "sdpmElement.h"

namespace sdpm
{

/**
 * @brief Quadranglular element
 * @authors Adrien Crovato
 */
class SDPM_API Quad4 : public Element
{
    sdpmVector3d _tgt0; ///< unit tangent vector (node 0 to node 2)
    sdpmVector3d _tgt1; ///< unit tangent vector (node 1 to node 3)

public:
    Quad4(size_t n, Tag *tag, std::vector<Node *> &nodes);
    ~Quad4() {}

    virtual ElType getType() const override { return ElType::QUAD4; }
#ifndef SWIG
    virtual void update(double beta) override;
    virtual sdpmVector3d computeGradient(std::vector<sdpmDouble> const &u) const override;
#endif
};

} // namespace sdpm

#endif // SDPMQUAD4_H
