/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPMWAKE_H
#define SDPMWAKE_H

#include "sdpm.h"
#include "sdpmGroup.h"
#include "sdpmTag.h"
#include <map>

namespace sdpm
{

/**
 * @brief Hold the wake attached to a lifting body
 * @authors Adrien Crovato
 */
class SDPM_API Wake : public Group
{
    std::map<Element *, std::pair<Element *, Element *>> _wwMap; ///< wing-wake map
    std::map<Element *, double> _lagMap;                         ///< time lag map

public:
    Wake(Mesh &msh, std::string const &name, Tag *const &wingTag, size_t nTe, double ux, std::map<Node *, Node *> const &iTeMap = {});
    ~Wake() {}

#ifndef SWIG
    std::map<Element *, std::pair<Element *, Element *>> const &getElMap() const
    {
        return _wwMap;
    }
    std::map<Element *, double> const &getLagMap() const { return _lagMap; }
    virtual void write(std::ostream &out) const override;
#endif
};

} // namespace sdpm

#endif // SDPMWAKE_H
