/*
 * Copyright 2023 University of Liège
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#ifndef SDPM_EXTRAS_H
#define SDPM_EXTRAS_H

#include "sdpm.h"
#include <ostream>
#include <vector>

namespace std
{
/**
 * @brief print a std::vector
 */
template <typename T>
ostream &operator<<(ostream &out, vector<T> const &v)
{
    out << '[';
    for (size_t i = 0; i < v.size(); ++i)
    {
        out << v[i];
        if (i != v.size() - 1)
            out << ", ";
    }
    out << ']';
    return out;
}
} // namespace std

namespace sdpm
{
/**
 * @brief convolve two vectors
 */
SDPM_API sdpmVectorXcd convolve(sdpmVectorXcd const &u, sdpmVectorXcd const &v)
{
    int m = static_cast<int>(u.size());
    int n = static_cast<int>(v.size());
    sdpmVectorXcd w = sdpmVectorXcd::Zero(n + m - 1);
    for (int i = 0; i < w.size(); ++i)
    {
        int jmin = (i - n + 1 >= 0) ? i - n + 1 : 0;
        int jmax = (i - m + 1 < 0) ? i : m - 1;
        for (int j = jmin; j <= jmax; ++j)
            w(i) += u(j) * v(i - j);
    }
    return w;
}
} // namespace sdpm

#endif // SDPM_EXTRAS_H
